/////////////////////////////////////////////////////////////////////////////
// Name:        ext/stc/cpp/st_constants.cpp
// Purpose:     constants for Wx::STC
// Author:      Marcus Friedlaender and Mattia Barbon
// Created:     23/05/2002
// RCS-ID:      $Id: st_constants.cpp 2947 2010-08-01 14:10:04Z mbarbon $
// Copyright:   (c) 2002-2006, 2008, 2010 Marcus Friedlaender and Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#include "cpp/constants.h"

#include "../wx-scintilla/include/WxScintilla.h"

double stc_constant( const char* name, int arg )
{
    // !package: Wx
    // !parser: sub { $_[0] =~ m<^\s*r\w*\(\s*(\w+)\s*\);\s*(?://(.*))?$> }
    // !tag: stc
#define r( n ) \
    if( strEQ( name, #n ) ) \
        return n;

    WX_PL_CONSTANT_INIT();
    if( strlen( name ) >= 7 )
        fl = name[6];
    else
        fl = 0;

    switch( fl )
    {
    case '4':
        r( wxSTC_4GL_BLOCK );
        r( wxSTC_4GL_BLOCK_ );
        r( wxSTC_4GL_CHARACTER );
        r( wxSTC_4GL_CHARACTER_ );
        r( wxSTC_4GL_COMMENT1 );
        r( wxSTC_4GL_COMMENT1_ );
        r( wxSTC_4GL_COMMENT2 );
        r( wxSTC_4GL_COMMENT2_ );
        r( wxSTC_4GL_COMMENT3 );
        r( wxSTC_4GL_COMMENT3_ );
        r( wxSTC_4GL_COMMENT4 );
        r( wxSTC_4GL_COMMENT4_ );
        r( wxSTC_4GL_COMMENT5 );
        r( wxSTC_4GL_COMMENT5_ );
        r( wxSTC_4GL_COMMENT6 );
        r( wxSTC_4GL_COMMENT6_ );
        r( wxSTC_4GL_DEFAULT );
        r( wxSTC_4GL_DEFAULT_ );
        r( wxSTC_4GL_END );
        r( wxSTC_4GL_END_ );
        r( wxSTC_4GL_IDENTIFIER );
        r( wxSTC_4GL_IDENTIFIER_ );
        r( wxSTC_4GL_NUMBER );
        r( wxSTC_4GL_NUMBER_ );
        r( wxSTC_4GL_OPERATOR );
        r( wxSTC_4GL_OPERATOR_ );
        r( wxSTC_4GL_PREPROCESSOR );
        r( wxSTC_4GL_PREPROCESSOR_ );
        r( wxSTC_4GL_STRING );
        r( wxSTC_4GL_STRING_ );
        r( wxSTC_4GL_WORD );
        r( wxSTC_4GL_WORD_ );
        break;
    case 'A':
        r( wxSTC_AVE_DEFAULT );
        r( wxSTC_AVE_COMMENT );
        r( wxSTC_AVE_NUMBER );
        r( wxSTC_AVE_WORD );
        r( wxSTC_AVE_STRING );
        r( wxSTC_AVE_ENUM );
        r( wxSTC_AVE_STRINGEOL );
        r( wxSTC_AVE_IDENTIFIER );
        r( wxSTC_AVE_OPERATOR );
        r( wxSTC_ADA_DEFAULT );
        r( wxSTC_ADA_NUMBER );
        r( wxSTC_ADA_WORD );
        r( wxSTC_ADA_STRING );
        r( wxSTC_ADA_CHARACTER );
        r( wxSTC_ADA_IDENTIFIER );
        r( wxSTC_ADA_STRINGEOL );
        r( wxSTC_ASM_DEFAULT );
        r( wxSTC_ASM_COMMENT );
        r( wxSTC_ASM_NUMBER );
        r( wxSTC_ASM_STRING );
        r( wxSTC_ASM_OPERATOR );
        r( wxSTC_ASM_IDENTIFIER );
        r( wxSTC_ASM_CPUINSTRUCTION );
        r( wxSTC_ASM_MATHINSTRUCTION );
        r( wxSTC_ASM_REGISTER );
        r( wxSTC_ASM_DIRECTIVE );
        r( wxSTC_ASM_DIRECTIVEOPERAND );
        r( wxSTC_ASM_COMMENTBLOCK );
        r( wxSTC_ASM_CHARACTER );
        r( wxSTC_ASM_STRINGEOL );
        r( wxSTC_ASM_EXTINSTRUCTION );
        r( wxSTC_ABAQUS_ARGUMENT );
        r( wxSTC_ABAQUS_COMMAND );
        r( wxSTC_ABAQUS_COMMENT );
        r( wxSTC_ABAQUS_COMMENTBLOCK );
        r( wxSTC_ABAQUS_DEFAULT );
        r( wxSTC_ABAQUS_FUNCTION );
        r( wxSTC_ABAQUS_NUMBER );
        r( wxSTC_ABAQUS_OPERATOR );
        r( wxSTC_ABAQUS_PROCESSOR );
        r( wxSTC_ABAQUS_SLASHCOMMAND );
        r( wxSTC_ABAQUS_STARCOMMAND );
        r( wxSTC_ABAQUS_STRING );
        r( wxSTC_ABAQUS_WORD );
        r( wxSTC_ADA_CHARACTEREOL );
        r( wxSTC_ADA_COMMENTLINE );
        r( wxSTC_ADA_DELIMITER );
        r( wxSTC_ADA_ILLEGAL );
        r( wxSTC_ADA_LABEL );
        r( wxSTC_ALPHA_NOALPHA );
        r( wxSTC_ALPHA_OPAQUE );
        r( wxSTC_ALPHA_TRANSPARENT );
        r( wxSTC_APDL_COMMAND );
        r( wxSTC_APDL_COMMENT );
        r( wxSTC_APDL_COMMENTBLOCK );
        r( wxSTC_APDL_DEFAULT );
        r( wxSTC_APDL_FUNCTION );
        r( wxSTC_APDL_NUMBER );
        r( wxSTC_APDL_PROCESSOR );
        r( wxSTC_APDL_ARGUMENT );
        r( wxSTC_APDL_OPERATOR );
        r( wxSTC_APDL_SLASHCOMMAND );
        r( wxSTC_APDL_STARCOMMAND );
        r( wxSTC_APDL_STRING );
        r( wxSTC_APDL_WORD );
        r( wxSTC_ASN1_ATTRIBUTE );
        r( wxSTC_ASN1_COMMENT );
        r( wxSTC_ASN1_DEFAULT );
        r( wxSTC_ASN1_DESCRIPTOR );
        r( wxSTC_ASN1_IDENTIFIER );
        r( wxSTC_ASN1_KEYWORD );
        r( wxSTC_ASN1_OID );
        r( wxSTC_ASN1_OPERATOR );
        r( wxSTC_ASN1_SCALAR );
        r( wxSTC_ASN1_STRING );
        r( wxSTC_ASN1_TYPE );
        r( wxSTC_ASY_CHARACTER );
        r( wxSTC_ASY_COMMENT );
        r( wxSTC_ASY_COMMENTLINE );
        r( wxSTC_ASY_COMMENTLINEDOC );
        r( wxSTC_ASY_DEFAULT );
        r( wxSTC_ASY_IDENTIFIER );
        r( wxSTC_ASY_NUMBER );
        r( wxSTC_ASY_OPERATOR );
        r( wxSTC_ASY_STRING );
        r( wxSTC_ASY_STRINGEOL );
        r( wxSTC_ASY_WORD );
        r( wxSTC_ASY_WORD2 );
        r( wxSTC_AU3_COMMENT );
        r( wxSTC_AU3_COMMENTBLOCK );
        r( wxSTC_AU3_DEFAULT );
        r( wxSTC_AU3_FUNCTION );
        r( wxSTC_AU3_KEYWORD );
        r( wxSTC_AU3_MACRO );
        r( wxSTC_AU3_NUMBER );
        r( wxSTC_AU3_OPERATOR );
        r( wxSTC_AU3_PREPROCESSOR );
        r( wxSTC_AU3_SENT );
        r( wxSTC_AU3_SPECIAL );
        r( wxSTC_AU3_STRING );
        r( wxSTC_AU3_COMOBJ );
        r( wxSTC_AU3_EXPAND );
        r( wxSTC_AU3_UDF );
        r( wxSTC_AU3_VARIABLE );
        r( wxSTC_AVE_WORD1 );
        r( wxSTC_AVE_WORD2 );
        r( wxSTC_AVE_WORD3 );
        r( wxSTC_AVE_WORD4 );
        r( wxSTC_AVE_WORD5 );
        r( wxSTC_AVE_WORD6 );
        r( wxSTC_ANNOTATION_HIDDEN );
        r( wxSTC_ANNOTATION_STANDARD );
        r( wxSTC_ANNOTATION_BOXED );
        break;
    case 'B':
        r( wxSTC_B_DEFAULT );
        r( wxSTC_B_COMMENT );
        r( wxSTC_B_NUMBER );
        r( wxSTC_B_KEYWORD );
        r( wxSTC_B_STRING );
        r( wxSTC_B_PREPROCESSOR );
        r( wxSTC_B_OPERATOR );
        r( wxSTC_B_IDENTIFIER );
        r( wxSTC_B_DATE );
        r( wxSTC_BAT_DEFAULT );
        r( wxSTC_BAT_COMMENT );
        r( wxSTC_BAT_WORD );
        r( wxSTC_BAT_LABEL );
        r( wxSTC_BAT_HIDE );
        r( wxSTC_BAT_COMMAND );
        r( wxSTC_BAT_IDENTIFIER );
        r( wxSTC_BAT_OPERATOR );
        r( wxSTC_BAAN_DEFAULT );
        r( wxSTC_BAAN_COMMENT );
        r( wxSTC_BAAN_COMMENTDOC );
        r( wxSTC_BAAN_NUMBER );
        r( wxSTC_BAAN_WORD );
        r( wxSTC_BAAN_STRING );
        r( wxSTC_BAAN_PREPROCESSOR );
        r( wxSTC_BAAN_OPERATOR );
        r( wxSTC_BAAN_IDENTIFIER );
        r( wxSTC_BAAN_STRINGEOL );
        r( wxSTC_BAAN_WORD2 );
        r( wxSTC_B_ASM );
        r( wxSTC_B_CONSTANT );
        r( wxSTC_B_KEYWORD2 );
        r( wxSTC_B_KEYWORD3 );
        r( wxSTC_B_KEYWORD4 );
        r( wxSTC_B_STRINGEOL );
        r( wxSTC_B_BINNUMBER );
        r( wxSTC_B_ERROR );
        r( wxSTC_B_HEXNUMBER );
        r( wxSTC_B_LABEL );
        break;
    case 'C':
        r( wxSTC_CHARSET_ANSI );
        r( wxSTC_CHARSET_DEFAULT );
        r( wxSTC_CHARSET_BALTIC );
        r( wxSTC_CHARSET_CHINESEBIG5 );
        r( wxSTC_CHARSET_EASTEUROPE );
        r( wxSTC_CHARSET_GB2312 );
        r( wxSTC_CHARSET_GREEK );
        r( wxSTC_CHARSET_HANGUL );
        r( wxSTC_CHARSET_MAC );
        r( wxSTC_CHARSET_OEM );
        r( wxSTC_CHARSET_RUSSIAN );
        r( wxSTC_CHARSET_SHIFTJIS );
        r( wxSTC_CHARSET_SYMBOL );
        r( wxSTC_CHARSET_TURKISH );
        r( wxSTC_CHARSET_JOHAB );
        r( wxSTC_CHARSET_HEBREW );
        r( wxSTC_CHARSET_ARABIC );
        r( wxSTC_CHARSET_VIETNAMESE );
        r( wxSTC_CHARSET_THAI );
        r( wxSTC_CHARSET_8859_15 );
        r( wxSTC_CHARSET_CYRILLIC );
        r( wxSTC_CASE_MIXED );
        r( wxSTC_CASE_UPPER );
        r( wxSTC_CASE_LOWER );
        r( wxSTC_CACHE_NONE );
        r( wxSTC_CACHE_CARET );
        r( wxSTC_CACHE_PAGE );
        r( wxSTC_CACHE_DOCUMENT );
        r( wxSTC_CURSORNORMAL );
        r( wxSTC_CURSORWAIT );
        r( wxSTC_CARET_SLOP );
        r( wxSTC_CARET_STRICT );
        r( wxSTC_CARET_JUMPS );
        r( wxSTC_CARET_EVEN );
        r( wxSTC_CARETSTYLE_BLOCK );
        r( wxSTC_CARETSTYLE_INVISIBLE );
        r( wxSTC_CARETSTYLE_LINE );
        r( wxSTC_C_DEFAULT );
        r( wxSTC_C_COMMENT );
        r( wxSTC_C_COMMENTLINE );
        r( wxSTC_C_COMMENTDOC );
        r( wxSTC_C_NUMBER );
        r( wxSTC_C_WORD );
        r( wxSTC_C_STRING );
        r( wxSTC_C_CHARACTER );
        r( wxSTC_C_UUID );
        r( wxSTC_C_PREPROCESSOR );
        r( wxSTC_C_OPERATOR );
        r( wxSTC_C_IDENTIFIER );
        r( wxSTC_C_STRINGEOL );
        r( wxSTC_C_VERBATIM );
        r( wxSTC_C_REGEX );
        r( wxSTC_C_COMMENTLINEDOC );
        r( wxSTC_C_WORD2 );
        r( wxSTC_C_COMMENTDOCKEYWORD );
        r( wxSTC_C_COMMENTDOCKEYWORDERROR );
        r( wxSTC_C_GLOBALCLASS );
        r( wxSTC_CONF_DEFAULT );
        r( wxSTC_CONF_COMMENT );
        r( wxSTC_CONF_NUMBER );
        r( wxSTC_CONF_IDENTIFIER );
        r( wxSTC_CONF_EXTENSION );
        r( wxSTC_CONF_PARAMETER );
        r( wxSTC_CONF_STRING );
        r( wxSTC_CONF_OPERATOR );
        r( wxSTC_CONF_IP );
        r( wxSTC_CONF_DIRECTIVE );
        r( wxSTC_CSS_DEFAULT );
        r( wxSTC_CSS_TAG );
        r( wxSTC_CSS_CLASS );
        r( wxSTC_CSS_PSEUDOCLASS );
        r( wxSTC_CSS_UNKNOWN_PSEUDOCLASS );
        r( wxSTC_CSS_OPERATOR );
        r( wxSTC_CSS_IDENTIFIER );
        r( wxSTC_CSS_UNKNOWN_IDENTIFIER );
        r( wxSTC_CSS_VALUE );
        r( wxSTC_CSS_COMMENT );
        r( wxSTC_CSS_ID );
        r( wxSTC_CSS_IMPORTANT );
        r( wxSTC_CSS_DIRECTIVE );
        r( wxSTC_CSS_DOUBLESTRING );
        r( wxSTC_CSS_SINGLESTRING );
        r( wxSTC_CSS_ATTRIBUTE );
        r( wxSTC_CSS_IDENTIFIER2 );
        r( wxSTC_CAML_CHAR );
        r( wxSTC_CAML_COMMENT );
        r( wxSTC_CAML_COMMENT1 );
        r( wxSTC_CAML_COMMENT2 );
        r( wxSTC_CAML_COMMENT3 );
        r( wxSTC_CAML_DEFAULT );
        r( wxSTC_CAML_IDENTIFIER );
        r( wxSTC_CAML_KEYWORD );
        r( wxSTC_CAML_KEYWORD2 );
        r( wxSTC_CAML_KEYWORD3 );
        r( wxSTC_CAML_LINENUM );
        r( wxSTC_CAML_NUMBER );
        r( wxSTC_CAML_OPERATOR );
        r( wxSTC_CAML_STRING );
        r( wxSTC_CAML_TAGNAME );
        r( wxSTC_CLW_ATTRIBUTE );
        r( wxSTC_CLW_BUILTIN_PROCEDURES_FUNCTION );
        r( wxSTC_CLW_COMMENT );
        r( wxSTC_CLW_COMPILER_DIRECTIVE );
        r( wxSTC_CLW_DEFAULT );
        r( wxSTC_CLW_ERROR );
        r( wxSTC_CLW_INTEGER_CONSTANT );
        r( wxSTC_CLW_KEYWORD );
        r( wxSTC_CLW_LABEL );
        r( wxSTC_CLW_PICTURE_STRING );
        r( wxSTC_CLW_REAL_CONSTANT );
        r( wxSTC_CLW_DEPRECATED );
        r( wxSTC_CLW_RUNTIME_EXPRESSIONS );
        r( wxSTC_CLW_STANDARD_EQUATE );
        r( wxSTC_CLW_STRING );
        r( wxSTC_CLW_STRUCTURE_DATA_TYPE );
        r( wxSTC_CLW_USER_IDENTIFIER );
        r( wxSTC_CMAKE_COMMANDS );
        r( wxSTC_CMAKE_COMMENT );
        r( wxSTC_CMAKE_DEFAULT );
        r( wxSTC_CMAKE_FOREACHDEF );
        r( wxSTC_CMAKE_IFDEFINEDEF );
        r( wxSTC_CMAKE_MACRODEF );
        r( wxSTC_CMAKE_NUMBER );
        r( wxSTC_CMAKE_PARAMETERS );
        r( wxSTC_CMAKE_STRINGDQ );
        r( wxSTC_CMAKE_STRINGLQ );
        r( wxSTC_CMAKE_STRINGRQ );
        r( wxSTC_CMAKE_STRINGVAR );
        r( wxSTC_CMAKE_USERDEFINED );
        r( wxSTC_CMAKE_VARIABLE );
        r( wxSTC_CMAKE_WHILEDEF );
        r( wxSTC_CP_DBCS );
        r( wxSTC_CP_UTF8 );
        r( wxSTC_CSOUND_ARATE_VAR );
        r( wxSTC_CSOUND_COMMENT );
        r( wxSTC_CSOUND_COMMENTBLOCK );
        r( wxSTC_CSOUND_DEFAULT );
        r( wxSTC_CSOUND_GLOBAL_VAR );
        r( wxSTC_CSOUND_HEADERSTMT );
        r( wxSTC_CSOUND_IDENTIFIER );
        r( wxSTC_CSOUND_INSTR );
        r( wxSTC_CSOUND_IRATE_VAR );
        r( wxSTC_CSOUND_KRATE_VAR );
        r( wxSTC_CSOUND_NUMBER );
        r( wxSTC_CSOUND_OPCODE );
        r( wxSTC_CSOUND_OPERATOR );
        r( wxSTC_CSOUND_PARAM );
        r( wxSTC_CSOUND_STRINGEOL );
        r( wxSTC_CSOUND_USERKEYWORD );
        break;
    case 'D':
        r( wxSTC_DIFF_DEFAULT );
        r( wxSTC_DIFF_COMMENT );
        r( wxSTC_DIFF_COMMAND );
        r( wxSTC_DIFF_HEADER );
        r( wxSTC_DIFF_POSITION );
        r( wxSTC_DIFF_DELETED );
        r( wxSTC_DIFF_ADDED );
        r( wxSTC_D_CHARACTER );
        r( wxSTC_D_COMMENT );
        r( wxSTC_D_COMMENTDOC );
        r( wxSTC_D_COMMENTDOCKEYWORD );
        r( wxSTC_D_COMMENTDOCKEYWORDERROR );
        r( wxSTC_D_COMMENTLINE );
        r( wxSTC_D_COMMENTLINEDOC );
        r( wxSTC_D_COMMENTNESTED );
        r( wxSTC_D_DEFAULT );
        r( wxSTC_D_IDENTIFIER );
        r( wxSTC_D_NUMBER );
        r( wxSTC_D_OPERATOR );
        r( wxSTC_D_STRING );
        r( wxSTC_D_STRINGEOL );
        r( wxSTC_D_TYPEDEF );
        r( wxSTC_D_WORD );
        r( wxSTC_D_WORD2 );
        r( wxSTC_D_WORD3 );
        break;
    case 'E':
        r( wxSTC_EOL_CR );
        r( wxSTC_EOL_LF );
        r( wxSTC_EOL_CRLF );
        r( wxSTC_EDGE_NONE );
        r( wxSTC_EDGE_LINE );
        r( wxSTC_EDGE_BACKGROUND );
        r( wxSTC_ERR_DEFAULT );
        r( wxSTC_ERR_PYTHON );
        r( wxSTC_ERR_GCC );
        r( wxSTC_ERR_MS );
        r( wxSTC_ERR_CMD );
        r( wxSTC_ERR_BORLAND );
        r( wxSTC_ERR_PERL );
        r( wxSTC_ERR_NET );
        r( wxSTC_ERR_LUA );
        r( wxSTC_ERR_CTAG );
        r( wxSTC_ERR_DIFF_CHANGED );
        r( wxSTC_ERR_DIFF_ADDITION );
        r( wxSTC_ERR_DIFF_DELETION );
        r( wxSTC_ERR_DIFF_MESSAGE );
        r( wxSTC_EIFFEL_DEFAULT );
        r( wxSTC_EIFFEL_COMMENTLINE );
        r( wxSTC_EIFFEL_NUMBER );
        r( wxSTC_EIFFEL_WORD );
        r( wxSTC_EIFFEL_STRING );
        r( wxSTC_EIFFEL_CHARACTER );
        r( wxSTC_EIFFEL_OPERATOR );
        r( wxSTC_EIFFEL_IDENTIFIER );
        r( wxSTC_EIFFEL_STRINGEOL );
        r( wxSTC_ERLANG_ATOM );
        r( wxSTC_ERLANG_CHARACTER );
        r( wxSTC_ERLANG_COMMENT );
        r( wxSTC_ERLANG_DEFAULT );
        r( wxSTC_ERLANG_FUNCTION_NAME );
        r( wxSTC_ERLANG_KEYWORD );
        r( wxSTC_ERLANG_MACRO );
        r( wxSTC_ERLANG_NODE_NAME );
        r( wxSTC_ERLANG_NUMBER );
        r( wxSTC_ERLANG_OPERATOR );
        r( wxSTC_ERLANG_RECORD );
        r( wxSTC_ERLANG_PREPROC );
        r( wxSTC_ERLANG_STRING );
        r( wxSTC_ERLANG_UNKNOWN );
        r( wxSTC_ERLANG_VARIABLE );
        r( wxSTC_ERR_ABSF );
        r( wxSTC_ERR_ELF );
        r( wxSTC_ERR_IFC );
        r( wxSTC_ERR_IFORT );
        r( wxSTC_ERR_JAVA_STACK );
        r( wxSTC_ERR_PHP );
        r( wxSTC_ERR_TIDY );
        r( wxSTC_ERR_VALUE );
        r( wxSTC_ESCRIPT_BRACE );
        r( wxSTC_ESCRIPT_COMMENT );
        r( wxSTC_ESCRIPT_COMMENTDOC );
        r( wxSTC_ESCRIPT_COMMENTLINE );
        r( wxSTC_ESCRIPT_DEFAULT );
        r( wxSTC_ESCRIPT_IDENTIFIER );
        r( wxSTC_ESCRIPT_NUMBER );
        r( wxSTC_ESCRIPT_OPERATOR );
        r( wxSTC_ESCRIPT_STRING );
        r( wxSTC_ESCRIPT_WORD );
        r( wxSTC_ESCRIPT_WORD2 );
        r( wxSTC_ESCRIPT_WORD3 );
        break;
    case 'F':
        r( wxSTC_FIND_WHOLEWORD );
        r( wxSTC_FIND_MATCHCASE );
        r( wxSTC_FIND_WORDSTART );
        r( wxSTC_FIND_REGEXP );
        r( wxSTC_FOLDLEVELBASE  );
        r( wxSTC_FOLDLEVELWHITEFLAG );
        r( wxSTC_FOLDLEVELHEADERFLAG );
        r( wxSTC_FOLDLEVELNUMBERMASK );
        r( wxSTC_FORTH_DEFAULT );
        r( wxSTC_FORTH_COMMENT );
        r( wxSTC_FORTH_COMMENT_ML );
        r( wxSTC_FORTH_IDENTIFIER );
        r( wxSTC_FORTH_CONTROL );
        r( wxSTC_FORTH_KEYWORD );
        r( wxSTC_FORTH_DEFWORD );
        r( wxSTC_FORTH_PREWORD1 );
        r( wxSTC_FORTH_PREWORD2 );
        r( wxSTC_FORTH_NUMBER );
        r( wxSTC_FORTH_STRING );
        r( wxSTC_FORTH_LOCALE );
        r( wxSTC_F_DEFAULT );
        r( wxSTC_F_COMMENT );
        r( wxSTC_F_NUMBER );
        r( wxSTC_F_STRING1 );
        r( wxSTC_F_STRING2 );
        r( wxSTC_F_STRINGEOL );
        r( wxSTC_F_OPERATOR );
        r( wxSTC_F_IDENTIFIER );
        r( wxSTC_F_WORD );
        r( wxSTC_F_WORD2 );
        r( wxSTC_F_WORD3 );
        r( wxSTC_F_PREPROCESSOR );
        r( wxSTC_F_OPERATOR2 );
        r( wxSTC_F_LABEL );
        r( wxSTC_F_CONTINUATION );
        r( wxSTC_FIND_POSIX );
        r( wxSTC_FOLDFLAG_LEVELNUMBERS );
        r( wxSTC_FOLDFLAG_LINEAFTER_CONTRACTED );
        r( wxSTC_FOLDFLAG_LINEAFTER_EXPANDED );
        r( wxSTC_FOLDFLAG_LINEBEFORE_CONTRACTED );
        r( wxSTC_FOLDFLAG_LINEBEFORE_EXPANDED );
        r( wxSTC_FS_ASM );
        r( wxSTC_FS_BINNUMBER );
        r( wxSTC_FS_COMMENT );
        r( wxSTC_FS_COMMENTDOC );
        r( wxSTC_FS_COMMENTDOCKEYWORD );
        r( wxSTC_FS_COMMENTDOCKEYWORDERROR );
        r( wxSTC_FS_COMMENTLINE );
        r( wxSTC_FS_COMMENTLINEDOC );
        r( wxSTC_FS_CONSTANT );
        r( wxSTC_FS_DATE );
        r( wxSTC_FS_DEFAULT );
        r( wxSTC_FS_ERROR );
        r( wxSTC_FS_HEXNUMBER );
        r( wxSTC_FS_IDENTIFIER );
        r( wxSTC_FS_KEYWORD );
        r( wxSTC_FS_KEYWORD2 );
        r( wxSTC_FS_KEYWORD3 );
        r( wxSTC_FS_KEYWORD4 );
        r( wxSTC_FS_LABEL );
        r( wxSTC_FS_NUMBER );
        r( wxSTC_FS_OPERATOR );
        r( wxSTC_FS_PREPROCESSOR );
        r( wxSTC_FS_STRING );
        r( wxSTC_FS_STRINGEOL );
        break;
    case 'G':
        r( wxSTC_GAP_CHAR );
        r( wxSTC_GAP_COMMENT );
        r( wxSTC_GAP_DEFAULT );
        r( wxSTC_GAP_IDENTIFIER );
        r( wxSTC_GAP_KEYWORD );
        r( wxSTC_GAP_KEYWORD2 );
        r( wxSTC_GAP_KEYWORD3 );
        r( wxSTC_GAP_KEYWORD4 );
        r( wxSTC_GAP_NUMBER );
        r( wxSTC_GAP_OPERATOR );
        r( wxSTC_GAP_STRING );
        r( wxSTC_GAP_STRINGEOL );
        r( wxSTC_GC_ATTRIBUTE );
        r( wxSTC_GC_COMMAND );
        r( wxSTC_GC_COMMENTBLOCK );
        r( wxSTC_GC_COMMENTLINE );
        r( wxSTC_GC_CONTROL );
        r( wxSTC_GC_DEFAULT );
        r( wxSTC_GC_EVENT );
        r( wxSTC_GC_GLOBAL );
        r( wxSTC_GC_OPERATOR );
        r( wxSTC_GC_STRING );
        break;
    case 'H':
        r( wxSTC_H_DEFAULT );
        r( wxSTC_H_TAG );
        r( wxSTC_H_TAGUNKNOWN );
        r( wxSTC_H_ATTRIBUTE );
        r( wxSTC_H_ATTRIBUTEUNKNOWN );
        r( wxSTC_H_NUMBER );
        r( wxSTC_H_DOUBLESTRING );
        r( wxSTC_H_SINGLESTRING );
        r( wxSTC_H_OTHER );
        r( wxSTC_H_COMMENT );
        r( wxSTC_H_ENTITY );
        r( wxSTC_H_TAGEND );
        r( wxSTC_H_XMLSTART );
        r( wxSTC_H_XMLEND );
        r( wxSTC_H_SCRIPT );
        r( wxSTC_H_ASP );
        r( wxSTC_H_ASPAT );
        r( wxSTC_H_CDATA );
        r( wxSTC_H_QUESTION );
        r( wxSTC_H_VALUE );
        r( wxSTC_H_XCCOMMENT );
        r( wxSTC_H_SGML_DEFAULT );
        r( wxSTC_H_SGML_COMMAND );
        r( wxSTC_H_SGML_1ST_PARAM );
        r( wxSTC_H_SGML_DOUBLESTRING );
        r( wxSTC_H_SGML_SIMPLESTRING );
        r( wxSTC_H_SGML_ERROR );
        r( wxSTC_H_SGML_SPECIAL );
        r( wxSTC_H_SGML_ENTITY );
        r( wxSTC_H_SGML_COMMENT );
        r( wxSTC_H_SGML_1ST_PARAM_COMMENT );
        r( wxSTC_H_SGML_BLOCK_DEFAULT );
        r( wxSTC_HJ_START );
        r( wxSTC_HJ_DEFAULT );
        r( wxSTC_HJ_COMMENT );
        r( wxSTC_HJ_COMMENTLINE );
        r( wxSTC_HJ_COMMENTDOC );
        r( wxSTC_HJ_NUMBER );
        r( wxSTC_HJ_WORD );
        r( wxSTC_HJ_KEYWORD );
        r( wxSTC_HJ_DOUBLESTRING );
        r( wxSTC_HJ_SINGLESTRING );
        r( wxSTC_HJ_SYMBOLS );
        r( wxSTC_HJ_STRINGEOL );
        r( wxSTC_HJ_REGEX );
        r( wxSTC_HJA_START );
        r( wxSTC_HJA_DEFAULT );
        r( wxSTC_HJA_COMMENT );
        r( wxSTC_HJA_COMMENTLINE );
        r( wxSTC_HJA_COMMENTDOC );
        r( wxSTC_HJA_NUMBER );
        r( wxSTC_HJA_WORD );
        r( wxSTC_HJA_KEYWORD );
        r( wxSTC_HJA_DOUBLESTRING );
        r( wxSTC_HJA_SINGLESTRING );
        r( wxSTC_HJA_SYMBOLS );
        r( wxSTC_HJA_STRINGEOL );
        r( wxSTC_HJA_REGEX );
        r( wxSTC_HB_START );
        r( wxSTC_HB_DEFAULT );
        r( wxSTC_HB_COMMENTLINE );
        r( wxSTC_HB_NUMBER );
        r( wxSTC_HB_WORD );
        r( wxSTC_HB_STRING );
        r( wxSTC_HB_IDENTIFIER );
        r( wxSTC_HB_STRINGEOL );
        r( wxSTC_HBA_START );
        r( wxSTC_HBA_DEFAULT );
        r( wxSTC_HBA_COMMENTLINE );
        r( wxSTC_HBA_NUMBER );
        r( wxSTC_HBA_WORD );
        r( wxSTC_HBA_STRING );
        r( wxSTC_HBA_IDENTIFIER );
        r( wxSTC_HBA_STRINGEOL );
        r( wxSTC_HP_START );
        r( wxSTC_HP_DEFAULT );
        r( wxSTC_HP_COMMENTLINE );
        r( wxSTC_HP_NUMBER );
        r( wxSTC_HP_STRING );
        r( wxSTC_HP_CHARACTER );
        r( wxSTC_HP_WORD );
        r( wxSTC_HP_TRIPLE );
        r( wxSTC_HP_TRIPLEDOUBLE );
        r( wxSTC_HP_CLASSNAME );
        r( wxSTC_HP_DEFNAME );
        r( wxSTC_HP_OPERATOR );
        r( wxSTC_HP_IDENTIFIER );
        r( wxSTC_HPA_START );
        r( wxSTC_HPA_DEFAULT );
        r( wxSTC_HPA_COMMENTLINE );
        r( wxSTC_HPA_NUMBER );
        r( wxSTC_HPA_STRING );
        r( wxSTC_HPA_CHARACTER );
        r( wxSTC_HPA_WORD );
        r( wxSTC_HPA_TRIPLE );
        r( wxSTC_HPA_TRIPLEDOUBLE );
        r( wxSTC_HPA_CLASSNAME );
        r( wxSTC_HPA_DEFNAME );
        r( wxSTC_HPA_OPERATOR );
        r( wxSTC_HPA_IDENTIFIER );
        r( wxSTC_HPHP_DEFAULT );
        r( wxSTC_HPHP_HSTRING );
        r( wxSTC_HPHP_SIMPLESTRING );
        r( wxSTC_HPHP_WORD );
        r( wxSTC_HPHP_NUMBER );
        r( wxSTC_HPHP_VARIABLE );
        r( wxSTC_HPHP_COMMENT );
        r( wxSTC_HPHP_COMMENTLINE );
        r( wxSTC_HPHP_HSTRING_VARIABLE );
        r( wxSTC_HPHP_OPERATOR );
        r( wxSTC_HPHP_COMPLEX_VARIABLE );
        r( wxSTC_HA_CAPITAL );
        r( wxSTC_HA_CHARACTER );
        r( wxSTC_HA_CLASS );
        r( wxSTC_HA_COMMENTBLOCK );
        r( wxSTC_HA_COMMENTBLOCK2 );
        r( wxSTC_HA_COMMENTBLOCK3 );
        r( wxSTC_HA_COMMENTLINE );
        r( wxSTC_HA_DATA );
        r( wxSTC_HA_DEFAULT );
        r( wxSTC_HA_IDENTIFIER );
        r( wxSTC_HA_IMPORT );
        r( wxSTC_HA_INSTANCE );
        r( wxSTC_HA_KEYWORD );
        r( wxSTC_HA_MODULE );
        r( wxSTC_HA_NUMBER );
        r( wxSTC_HA_OPERATOR );
        r( wxSTC_HA_STRING );
        break;
    case 'I':
        r( wxSTC_INDIC_MAX );
        r( wxSTC_INDIC_PLAIN );
        r( wxSTC_INDIC_SQUIGGLE );
        r( wxSTC_INDIC_TT );
        r( wxSTC_INDIC_DIAGONAL );
        r( wxSTC_INDIC_STRIKE );
        r( wxSTC_INDIC0_MASK );
        r( wxSTC_INDIC1_MASK );
        r( wxSTC_INDIC2_MASK );
        r( wxSTC_INDICS_MASK );
        r( wxSTC_INDIC_BOX );
        r( wxSTC_INDIC_CONTAINER );
        r( wxSTC_INDIC_HIDDEN );
        r( wxSTC_INDIC_ROUNDBOX );
        r( wxSTC_INDIC_SQUIGGLELOW );
        r( wxSTC_INDIC_DASH );
        r( wxSTC_INDIC_DOTS );
        r( wxSTC_INDIC_DOTBOX );
        r( wxSTC_INDIC_STRAIGHTBOX );
        r( wxSTC_INNO_COMMENT );
        r( wxSTC_INNO_COMMENT_PASCAL );
        r( wxSTC_INNO_DEFAULT );
        r( wxSTC_INNO_IDENTIFIER );
        r( wxSTC_INNO_KEYWORD );
        r( wxSTC_INNO_KEYWORD_PASCAL );
        r( wxSTC_INNO_KEYWORD_USER );
        r( wxSTC_INNO_PARAMETER );
        r( wxSTC_INNO_PREPROC );
        r( wxSTC_INNO_INLINE_EXPANSION );
        r( wxSTC_INNO_SECTION );
        r( wxSTC_INNO_STRING_DOUBLE );
        r( wxSTC_INNO_STRING_SINGLE );
        r( wxSTC_INVALID_POSITION );
        r( wxSTC_IV_LOOKBOTH );
        r( wxSTC_IV_LOOKFORWARD );
        r( wxSTC_IV_NONE );
        r( wxSTC_IV_REAL );
        break;
    case 'K':
        r( wxSTC_KEY_DOWN );
        r( wxSTC_KEY_UP );
        r( wxSTC_KEY_LEFT );
        r( wxSTC_KEY_RIGHT );
        r( wxSTC_KEY_HOME );
        r( wxSTC_KEY_END );
        r( wxSTC_KEY_PRIOR );
        r( wxSTC_KEY_NEXT );
        r( wxSTC_KEY_DELETE );
        r( wxSTC_KEY_INSERT );
        r( wxSTC_KEY_ESCAPE );
        r( wxSTC_KEY_BACK );
        r( wxSTC_KEY_TAB );
        r( wxSTC_KEY_RETURN );
        r( wxSTC_KEY_ADD );
        r( wxSTC_KEY_SUBTRACT );
        r( wxSTC_KEY_DIVIDE );
        r( wxSTC_KEYWORDSET_MAX );
        r( wxSTC_KEY_MENU );
        r( wxSTC_KEY_RWIN );
        r( wxSTC_KEY_WIN );
        r( wxSTC_KIX_COMMENT );
        r( wxSTC_KIX_DEFAULT );
        r( wxSTC_KIX_FUNCTIONS );
        r( wxSTC_KIX_IDENTIFIER );
        r( wxSTC_KIX_KEYWORD );
        r( wxSTC_KIX_MACRO );
        r( wxSTC_KIX_NUMBER );
        r( wxSTC_KIX_OPERATOR );
        r( wxSTC_KIX_STRING1 );
        r( wxSTC_KIX_STRING2 );
        r( wxSTC_KIX_VAR );
        break;
    case 'L':
        r( wxSTC_LEX_ADA );
        r( wxSTC_LEX_ASM );
#ifdef wxSTC_LEX_ASP
        r( wxSTC_LEX_ASP );
#endif
        r( wxSTC_LEX_AUTOMATIC );
        r( wxSTC_LEX_AVE );
        r( wxSTC_LEX_BAAN );
        r( wxSTC_LEX_BATCH );
        r( wxSTC_LEX_BULLANT );
        r( wxSTC_LEX_CONF );
        r( wxSTC_LEX_CONTAINER );
        r( wxSTC_LEX_CPP );
        r( wxSTC_LEX_CSS );
        r( wxSTC_LEX_DIFF );
        r( wxSTC_LEX_EIFFEL );
        r( wxSTC_LEX_EIFFELKW );
        r( wxSTC_LEX_ERRORLIST );
        r( wxSTC_LEX_FORTH );
        r( wxSTC_LEX_FORTRAN );
        r( wxSTC_LEX_HTML );
        r( wxSTC_LEX_LATEX );
        r( wxSTC_LEX_LISP );
        r( wxSTC_LEX_LUA );
        r( wxSTC_LEX_MAKEFILE );
        r( wxSTC_LEX_MATLAB );
        r( wxSTC_LEX_NNCRONTAB );
        r( wxSTC_LEX_NULL );
        r( wxSTC_LEX_NSIS );
        r( wxSTC_LEX_PASCAL );
        r( wxSTC_LEX_PERL );
#ifdef wxSTC_LEX_PHP
        r( wxSTC_LEX_PHP );
#endif
#ifdef wxSTC_LEX_PHPSCRIPT
        r( wxSTC_LEX_PHPSCRIPT );
#endif
        r( wxSTC_LEX_PROPERTIES );
        r( wxSTC_LEX_PS );
        r( wxSTC_LEX_PYTHON );
        r( wxSTC_LEX_RUBY );
        r( wxSTC_LEX_SCRIPTOL );
        r( wxSTC_LEX_SQL );
        r( wxSTC_LEX_TCL );
        r( wxSTC_LEX_YAML );
        r( wxSTC_LEX_TEX );
        r( wxSTC_LEX_VB );
        r( wxSTC_LEX_VBSCRIPT );
        r( wxSTC_LEX_XCODE );
        r( wxSTC_LEX_XML );
        r( wxSTC_LEX_ABAQUS );
        r( wxSTC_LEX_APDL );
        r( wxSTC_LEX_ASN1 );
        r( wxSTC_LEX_ASYMPTOTE );
        r( wxSTC_LEX_AU3 );
        r( wxSTC_LEX_BASH );
        r( wxSTC_LEX_BLITZBASIC );
        r( wxSTC_LEX_CAML );
        r( wxSTC_LEX_CLW );
        r( wxSTC_LEX_CLWNOCASE );
        r( wxSTC_LEX_CMAKE );
        r( wxSTC_LEX_CPPNOCASE );
        r( wxSTC_LEX_CSOUND );
        r( wxSTC_LEX_D );
        r( wxSTC_LEX_ERLANG );
        r( wxSTC_LEX_ESCRIPT );
        r( wxSTC_LEX_F77 );
        r( wxSTC_LEX_FLAGSHIP );
        r( wxSTC_LEX_FREEBASIC );
        r( wxSTC_LEX_GAP );
        r( wxSTC_LEX_GUI4CLI );
        r( wxSTC_LEX_HASKELL );
        r( wxSTC_LEX_INNOSETUP );
        r( wxSTC_LEX_KIX );
        r( wxSTC_LEX_LOT );
        r( wxSTC_LEX_LOUT );
        r( wxSTC_LEX_METAPOST );
        r( wxSTC_LEX_MMIXAL );
        r( wxSTC_LEX_MSSQL );
        r( wxSTC_LEX_OCTAVE );
        r( wxSTC_LEX_OPAL );
        r( wxSTC_LEX_PLM );
        r( wxSTC_LEX_POV );
        r( wxSTC_LEX_POWERBASIC );
        r( wxSTC_LEX_PROGRESS );
        r( wxSTC_LEX_PUREBASIC );
        r( wxSTC_LEX_R );
        r( wxSTC_LEX_REBOL );
        r( wxSTC_LEX_SMALLTALK );
        r( wxSTC_LEX_SPECMAN );
        r( wxSTC_LEX_SPICE );
        r( wxSTC_LEX_TADS3 );
        r( wxSTC_LEX_VERILOG );
        r( wxSTC_LEX_VHDL );
        r( wxSTC_LASTSTEPINUNDOREDO );
        r( wxSTC_L_DEFAULT );
        r( wxSTC_L_COMMAND );
        r( wxSTC_L_TAG );
        r( wxSTC_L_MATH );
        r( wxSTC_L_COMMENT );
        r( wxSTC_LUA_DEFAULT );
        r( wxSTC_LUA_COMMENT );
        r( wxSTC_LUA_COMMENTLINE );
        r( wxSTC_LUA_COMMENTDOC );
        r( wxSTC_LUA_NUMBER );
        r( wxSTC_LUA_WORD );
        r( wxSTC_LUA_STRING );
        r( wxSTC_LUA_CHARACTER );
        r( wxSTC_LUA_LITERALSTRING );
        r( wxSTC_LUA_PREPROCESSOR );
        r( wxSTC_LUA_OPERATOR );
        r( wxSTC_LUA_IDENTIFIER );
        r( wxSTC_LUA_STRINGEOL );
        r( wxSTC_LUA_WORD2 );
        r( wxSTC_LUA_WORD3 );
        r( wxSTC_LUA_WORD4 );
        r( wxSTC_LUA_WORD5 );
        r( wxSTC_LUA_WORD6 );
        r( wxSTC_LISP_DEFAULT );
        r( wxSTC_LISP_COMMENT );
        r( wxSTC_LISP_NUMBER );
        r( wxSTC_LISP_KEYWORD );
        r( wxSTC_LISP_STRING );
        r( wxSTC_LISP_STRINGEOL );
        r( wxSTC_LISP_IDENTIFIER );
        r( wxSTC_LISP_OPERATOR );
        r( wxSTC_LISP_KEYWORD_KW );
        r( wxSTC_LISP_MULTI_COMMENT );
        r( wxSTC_LISP_SPECIAL );
        r( wxSTC_LISP_SYMBOL );
        r( wxSTC_LEXER_START );
        r( wxSTC_LOT_ABORT );
        r( wxSTC_LOT_BREAK );
        r( wxSTC_LOT_DEFAULT );
        r( wxSTC_LOT_FAIL );
        r( wxSTC_LOT_HEADER );
        r( wxSTC_LOT_PASS );
        r( wxSTC_LOT_SET );
        r( wxSTC_LOUT_COMMENT );
        r( wxSTC_LOUT_DEFAULT );
        r( wxSTC_LOUT_IDENTIFIER );
        r( wxSTC_LOUT_NUMBER );
        r( wxSTC_LOUT_OPERATOR );
        r( wxSTC_LOUT_STRING );
        r( wxSTC_LOUT_STRINGEOL );
        r( wxSTC_LOUT_WORD );
        r( wxSTC_LOUT_WORD2 );
        r( wxSTC_LOUT_WORD3 );
        r( wxSTC_LOUT_WORD4 );
        r( wxSTC_LUA_WORD7 );
        r( wxSTC_LUA_WORD8 );
        break;
    case 'M':
        r( wxSTC_MARKER_MAX );
        r( wxSTC_MARK_CIRCLE );
        r( wxSTC_MARK_ROUNDRECT );
        r( wxSTC_MARK_ARROW );
        r( wxSTC_MARK_SMALLRECT );
        r( wxSTC_MARK_SHORTARROW );
        r( wxSTC_MARK_EMPTY );
        r( wxSTC_MARK_ARROWDOWN );
        r( wxSTC_MARK_MINUS );
        r( wxSTC_MARK_PLUS );
        r( wxSTC_MARK_VLINE );
        r( wxSTC_MARK_LCORNER );
        r( wxSTC_MARK_TCORNER );
        r( wxSTC_MARK_BOXPLUS );
        r( wxSTC_MARK_BOXPLUSCONNECTED );
        r( wxSTC_MARK_BOXMINUS );
        r( wxSTC_MARK_BOXMINUSCONNECTED );
        r( wxSTC_MARK_LCORNERCURVE );
        r( wxSTC_MARK_TCORNERCURVE );
        r( wxSTC_MARK_CIRCLEPLUS );
        r( wxSTC_MARK_CIRCLEPLUSCONNECTED );
        r( wxSTC_MARK_CIRCLEMINUS );
        r( wxSTC_MARK_CIRCLEMINUSCONNECTED );
        r( wxSTC_MARK_BACKGROUND );
        r( wxSTC_MARK_DOTDOTDOT );
        r( wxSTC_MARK_ARROWS );
        r( wxSTC_MARK_CHARACTER );
        r( wxSTC_MARK_FULLRECT );
        r( wxSTC_MARK_PIXMAP );
        r( wxSTC_MARKNUM_FOLDEREND );
        r( wxSTC_MARKNUM_FOLDEROPENMID );
        r( wxSTC_MARKNUM_FOLDERMIDTAIL );
        r( wxSTC_MARKNUM_FOLDERTAIL );
        r( wxSTC_MARKNUM_FOLDERSUB );
        r( wxSTC_MARKNUM_FOLDER );
        r( wxSTC_MARKNUM_FOLDEROPEN );
        r( wxSTC_MASK_FOLDERS );
        r( wxSTC_MARGIN_SYMBOL );
        r( wxSTC_MARGIN_NUMBER );
        r( wxSTC_MARGIN_BACK );
        r( wxSTC_MARGIN_FORE );
        r( wxSTC_MOD_INSERTTEXT );
        r( wxSTC_MOD_DELETETEXT );
        r( wxSTC_MOD_CHANGESTYLE );
        r( wxSTC_MOD_CHANGEFOLD );
        r( wxSTC_MOD_CHANGEMARKER );
        r( wxSTC_MOD_BEFOREINSERT );
        r( wxSTC_MOD_BEFOREDELETE );
        r( wxSTC_MODEVENTMASKALL );
        r( wxSTC_MAKE_DEFAULT );
        r( wxSTC_MAKE_COMMENT );
        r( wxSTC_MAKE_PREPROCESSOR );
        r( wxSTC_MAKE_IDENTIFIER );
        r( wxSTC_MAKE_OPERATOR );
        r( wxSTC_MAKE_TARGET );
        r( wxSTC_MAKE_IDEOL );
        r( wxSTC_MATLAB_DEFAULT );
        r( wxSTC_MATLAB_COMMENT );
        r( wxSTC_MATLAB_COMMAND );
        r( wxSTC_MATLAB_NUMBER );
        r( wxSTC_MATLAB_KEYWORD );
        r( wxSTC_MATLAB_STRING );
        r( wxSTC_MATLAB_OPERATOR );
        r( wxSTC_MATLAB_IDENTIFIER );
        r( wxSTC_MATLAB_DOUBLEQUOTESTRING );
        r( wxSTC_METAPOST_COMMAND );
        r( wxSTC_METAPOST_DEFAULT );
        r( wxSTC_METAPOST_EXTRA );
        r( wxSTC_METAPOST_GROUP );
        r( wxSTC_METAPOST_SPECIAL );
        r( wxSTC_METAPOST_SYMBOL );
        r( wxSTC_METAPOST_TEXT );
        r( wxSTC_MMIXAL_CHAR );
        r( wxSTC_MMIXAL_COMMENT );
        r( wxSTC_MMIXAL_HEX );
        r( wxSTC_MMIXAL_INCLUDE );
        r( wxSTC_MMIXAL_LABEL );
        r( wxSTC_MMIXAL_LEADWS );
        r( wxSTC_MMIXAL_NUMBER );
        r( wxSTC_MMIXAL_OPCODE );
        r( wxSTC_MMIXAL_OPCODE_POST );
        r( wxSTC_MMIXAL_OPCODE_PRE );
        r( wxSTC_MMIXAL_OPCODE_UNKNOWN );
        r( wxSTC_MMIXAL_OPCODE_VALID );
        r( wxSTC_MMIXAL_OPERANDS );
        r( wxSTC_MMIXAL_OPERATOR );
        r( wxSTC_MMIXAL_REF );
        r( wxSTC_MMIXAL_REGISTER );
        r( wxSTC_MMIXAL_STRING );
        r( wxSTC_MMIXAL_SYMBOL );
        r( wxSTC_MOD_CHANGEINDICATOR );
        r( wxSTC_MOD_CHANGELINESTATE );
        r( wxSTC_MSSQL_COLUMN_NAME );
        r( wxSTC_MSSQL_COLUMN_NAME_2 );
        r( wxSTC_MSSQL_COMMENT );
        r( wxSTC_MSSQL_DATATYPE );
        r( wxSTC_MSSQL_DEFAULT );
        r( wxSTC_MSSQL_DEFAULT_PREF_DATATYPE );
        r( wxSTC_MSSQL_FUNCTION );
        r( wxSTC_MSSQL_GLOBAL_VARIABLE );
        r( wxSTC_MSSQL_IDENTIFIER );
        r( wxSTC_MSSQL_LINE_COMMENT );
        r( wxSTC_MSSQL_NUMBER );
        r( wxSTC_MSSQL_OPERATOR );
        r( wxSTC_MSSQL_STATEMENT );
        r( wxSTC_MSSQL_STORED_PROCEDURE );
        r( wxSTC_MSSQL_STRING );
        r( wxSTC_MSSQL_SYSTABLE );
        r( wxSTC_MSSQL_VARIABLE );
        r( wxSTC_MULTILINEUNDOREDO );
        r( wxSTC_MULTISTEPUNDOREDO );
        break;
    case 'N':
        r( wxSTC_NNCRONTAB_DEFAULT );
        r( wxSTC_NNCRONTAB_COMMENT );
        r( wxSTC_NNCRONTAB_TASK );
        r( wxSTC_NNCRONTAB_SECTION );
        r( wxSTC_NNCRONTAB_KEYWORD );
        r( wxSTC_NNCRONTAB_MODIFIER );
        r( wxSTC_NNCRONTAB_ASTERISK );
        r( wxSTC_NNCRONTAB_NUMBER );
        r( wxSTC_NNCRONTAB_STRING );
        r( wxSTC_NNCRONTAB_ENVIRONMENT );
        r( wxSTC_NNCRONTAB_IDENTIFIER );

        r( wxSTC_NSIS_DEFAULT );
        r( wxSTC_NSIS_COMMENT );
        r( wxSTC_NSIS_STRINGDQ );
        r( wxSTC_NSIS_STRINGLQ );
        r( wxSTC_NSIS_STRINGRQ );
        r( wxSTC_NSIS_FUNCTION );
        r( wxSTC_NSIS_VARIABLE );
        r( wxSTC_NSIS_LABEL );
        r( wxSTC_NSIS_USERDEFINED );
        r( wxSTC_NSIS_SECTIONDEF );
        r( wxSTC_NSIS_SUBSECTIONDEF );
        r( wxSTC_NSIS_IFDEFINEDEF );
        r( wxSTC_NSIS_MACRODEF );
        r( wxSTC_NSIS_STRINGVAR );
        r( wxSTC_NSIS_NUMBER );
        r( wxSTC_NSIS_COMMENTBOX );
        r( wxSTC_NSIS_FUNCTIONDEF );
        r( wxSTC_NSIS_PAGEEX );
        r( wxSTC_NSIS_SECTIONGROUP );
        break;
    case 'O':
        r( wxSTC_OPAL_BOOL_CONST );
        r( wxSTC_OPAL_COMMENT_BLOCK );
        r( wxSTC_OPAL_COMMENT_LINE );
        r( wxSTC_OPAL_DEFAULT );
        r( wxSTC_OPAL_INTEGER );
        r( wxSTC_OPAL_KEYWORD );
        r( wxSTC_OPAL_PAR );
        r( wxSTC_OPAL_SORT );
        r( wxSTC_OPAL_SPACE );
        r( wxSTC_OPAL_STRING );
        r( wxSTC_OPTIONAL_START );
        break;
    case 'P':
        r( wxSTC_PRINT_NORMAL );
        r( wxSTC_PRINT_INVERTLIGHT );
        r( wxSTC_PRINT_BLACKONWHITE );
        r( wxSTC_PRINT_COLOURONWHITE );
        r( wxSTC_PRINT_COLOURONWHITEDEFAULTBG );
        r( wxSTC_PERFORMED_USER );
        r( wxSTC_PERFORMED_UNDO );
        r( wxSTC_PERFORMED_REDO );
        r( wxSTC_P_DEFAULT );
        r( wxSTC_P_COMMENTLINE );
        r( wxSTC_P_NUMBER );
        r( wxSTC_P_STRING );
        r( wxSTC_P_CHARACTER );
        r( wxSTC_P_WORD );
        r( wxSTC_P_TRIPLE );
        r( wxSTC_P_TRIPLEDOUBLE );
        r( wxSTC_P_CLASSNAME );
        r( wxSTC_P_DEFNAME );
        r( wxSTC_P_OPERATOR );
        r( wxSTC_P_IDENTIFIER );
        r( wxSTC_P_COMMENTBLOCK );
        r( wxSTC_P_STRINGEOL );
        r( wxSTC_P_DECORATOR );
        r( wxSTC_P_WORD2 );
        r( wxSTC_PL_DEFAULT );
        r( wxSTC_PL_ERROR );
        r( wxSTC_PL_COMMENTLINE );
        r( wxSTC_PL_POD );
        r( wxSTC_PL_NUMBER );
        r( wxSTC_PL_WORD );
        r( wxSTC_PL_STRING );
        r( wxSTC_PL_CHARACTER );
        r( wxSTC_PL_PUNCTUATION );
        r( wxSTC_PL_PREPROCESSOR );
        r( wxSTC_PL_OPERATOR );
        r( wxSTC_PL_IDENTIFIER );
        r( wxSTC_PL_SCALAR );
        r( wxSTC_PL_ARRAY );
        r( wxSTC_PL_HASH );
        r( wxSTC_PL_SYMBOLTABLE );
        r( wxSTC_PL_REGEX );
        r( wxSTC_PL_REGSUBST );
        r( wxSTC_PL_LONGQUOTE );
        r( wxSTC_PL_BACKTICKS );
        r( wxSTC_PL_DATASECTION );
        r( wxSTC_PL_HERE_DELIM );
        r( wxSTC_PL_HERE_Q );
        r( wxSTC_PL_HERE_QQ );
        r( wxSTC_PL_HERE_QX );
        r( wxSTC_PL_STRING_Q );
        r( wxSTC_PL_STRING_QQ );
        r( wxSTC_PL_STRING_QX );
        r( wxSTC_PL_STRING_QR );
        r( wxSTC_PL_STRING_QW );
        r( wxSTC_PL_FORMAT );
        r( wxSTC_PL_FORMAT_IDENT );
        r( wxSTC_PL_SUB_PROTOTYPE );
        r( wxSTC_PL_POD_VERB );
        r( wxSTC_PL_VARIABLE_INDEXER );
        r( wxSTC_PL_XLAT );
        r( wxSTC_PL_STRING_VAR );
        r( wxSTC_PL_REGEX_VAR );
        r( wxSTC_PL_REGSUBST_VAR );
        r( wxSTC_PL_BACKTICKS_VAR );
        r( wxSTC_PL_HERE_QQ_VAR );
        r( wxSTC_PL_HERE_QX_VAR );
        r( wxSTC_PL_STRING_QQ_VAR );
        r( wxSTC_PL_STRING_QX_VAR );
        r( wxSTC_PL_STRING_QR_VAR );
        r( wxSTC_PROPS_DEFAULT );
        r( wxSTC_PROPS_COMMENT );
        r( wxSTC_PROPS_SECTION );
        r( wxSTC_PROPS_ASSIGNMENT );
        r( wxSTC_PROPS_DEFVAL );
        r( wxSTC_PROPS_KEY );

        r( wxSTC_PS_DEFAULT );
        r( wxSTC_PS_COMMENT );
        r( wxSTC_PS_DSC_COMMENT );
        r( wxSTC_PS_DSC_VALUE );
        r( wxSTC_PS_NUMBER );
        r( wxSTC_PS_NAME );
        r( wxSTC_PS_KEYWORD );
        r( wxSTC_PS_LITERAL );
        r( wxSTC_PS_IMMEVAL );
        r( wxSTC_PS_PAREN_ARRAY );
        r( wxSTC_PS_PAREN_DICT );
        r( wxSTC_PS_PAREN_PROC );
        r( wxSTC_PS_TEXT );
        r( wxSTC_PS_HEXSTRING );
        r( wxSTC_PS_BASE85STRING );
        r( wxSTC_PS_BADSTRINGCHAR );
        r( wxSTC_PLM_COMMENT );
        r( wxSTC_PLM_CONTROL );
        r( wxSTC_PLM_DEFAULT );
        r( wxSTC_PLM_IDENTIFIER );
        r( wxSTC_PLM_KEYWORD );
        r( wxSTC_PLM_NUMBER );
        r( wxSTC_PLM_OPERATOR );
        r( wxSTC_PLM_STRING );
        r( wxSTC_POV_BADDIRECTIVE );
        r( wxSTC_POV_COMMENT );
        r( wxSTC_POV_COMMENTLINE );
        r( wxSTC_POV_DEFAULT );
        r( wxSTC_POV_DIRECTIVE );
        r( wxSTC_POV_IDENTIFIER );
        r( wxSTC_POV_NUMBER );
        r( wxSTC_POV_OPERATOR );
        r( wxSTC_POV_STRING );
        r( wxSTC_POV_STRINGEOL );
        r( wxSTC_POV_WORD2 );
        r( wxSTC_POV_WORD3 );
        r( wxSTC_POV_WORD4 );
        r( wxSTC_POV_WORD5 );
        r( wxSTC_POV_WORD6 );
        r( wxSTC_POV_WORD7 );
        r( wxSTC_POV_WORD8 );
        break;
    case 'R':
        r( wxSTC_RB_BACKTICKS );
        r( wxSTC_RB_CHARACTER );
        r( wxSTC_RB_CLASSNAME );
        r( wxSTC_RB_CLASS_VAR );
        r( wxSTC_RB_COMMENTLINE );
        r( wxSTC_RB_DATASECTION );
        r( wxSTC_RB_DEFAULT );
        r( wxSTC_RB_DEFNAME );
        r( wxSTC_RB_ERROR );
        r( wxSTC_RB_GLOBAL );
        r( wxSTC_RB_HERE_DELIM );
        r( wxSTC_RB_HERE_Q );
        r( wxSTC_RB_HERE_QQ );
        r( wxSTC_RB_HERE_QX );
        r( wxSTC_RB_IDENTIFIER );
        r( wxSTC_RB_INSTANCE_VAR );
        r( wxSTC_RB_MODULE_NAME );
        r( wxSTC_RB_NUMBER );
        r( wxSTC_RB_OPERATOR );
        r( wxSTC_RB_POD );
        r( wxSTC_RB_REGEX );
        r( wxSTC_RB_STDERR );
        r( wxSTC_RB_STDIN );
        r( wxSTC_RB_STDOUT );
        r( wxSTC_RB_STRING );
        r( wxSTC_RB_STRING_Q );
        r( wxSTC_RB_STRING_QQ );
        r( wxSTC_RB_STRING_QR );
        r( wxSTC_RB_STRING_QW );
        r( wxSTC_RB_STRING_QX );
        r( wxSTC_RB_SYMBOL );
        r( wxSTC_RB_UPPER_BOUND );
        r( wxSTC_RB_WORD );
        r( wxSTC_RB_WORD_DEMOTED );
        r( wxSTC_REBOL_BINARY );
        r( wxSTC_REBOL_BRACEDSTRING );
        r( wxSTC_REBOL_CHARACTER );
        r( wxSTC_REBOL_COMMENTBLOCK );
        r( wxSTC_REBOL_COMMENTLINE );
        r( wxSTC_REBOL_DATE );
        r( wxSTC_REBOL_DEFAULT );
        r( wxSTC_REBOL_EMAIL );
        r( wxSTC_REBOL_FILE );
        r( wxSTC_REBOL_IDENTIFIER );
        r( wxSTC_REBOL_ISSUE );
        r( wxSTC_REBOL_MONEY );
        r( wxSTC_REBOL_NUMBER );
        r( wxSTC_REBOL_OPERATOR );
        r( wxSTC_REBOL_PAIR );
        r( wxSTC_REBOL_PREFACE );
        r( wxSTC_REBOL_QUOTEDSTRING );
        r( wxSTC_REBOL_TAG );
        r( wxSTC_REBOL_TIME );
        r( wxSTC_REBOL_TUPLE );
        r( wxSTC_REBOL_URL );
        r( wxSTC_REBOL_WORD );
        r( wxSTC_REBOL_WORD2 );
        r( wxSTC_REBOL_WORD3 );
        r( wxSTC_REBOL_WORD4 );
        r( wxSTC_REBOL_WORD5 );
        r( wxSTC_REBOL_WORD6 );
        r( wxSTC_REBOL_WORD7 );
        r( wxSTC_REBOL_WORD8 );
        r( wxSTC_R_BASEKWORD );
        r( wxSTC_R_COMMENT );
        r( wxSTC_R_DEFAULT );
        r( wxSTC_R_IDENTIFIER );
        r( wxSTC_R_INFIX );
        r( wxSTC_R_INFIXEOL );
        r( wxSTC_R_KWORD );
        r( wxSTC_R_NUMBER );
        r( wxSTC_R_OPERATOR );
        r( wxSTC_R_OTHERKWORD );
        r( wxSTC_R_STRING );
        r( wxSTC_R_STRING2 );
        break;
    case 'S':
        r( wxSTC_STYLE_DEFAULT );
        r( wxSTC_STYLE_LINENUMBER );
        r( wxSTC_STYLE_BRACELIGHT );
        r( wxSTC_STYLE_BRACEBAD );
        r( wxSTC_STYLE_CONTROLCHAR );
        r( wxSTC_STYLE_INDENTGUIDE );
        r( wxSTC_STYLE_LASTPREDEFINED );
        r( wxSTC_STYLE_CALLTIP );
        r( wxSTC_STYLE_MAX );
        r( wxSTC_SCMOD_SHIFT );
        r( wxSTC_SCMOD_CTRL );
        r( wxSTC_SCMOD_ALT );
        r( wxSTC_SCMOD_NORM );
        r( wxSTC_SCRIPTOL_DEFAULT );
        r( wxSTC_SCRIPTOL_COMMENTLINE );
        r( wxSTC_SCRIPTOL_NUMBER );
        r( wxSTC_SCRIPTOL_STRING );
        r( wxSTC_SCRIPTOL_CHARACTER );
        r( wxSTC_SCRIPTOL_PREPROCESSOR );
        r( wxSTC_SCRIPTOL_OPERATOR );
        r( wxSTC_SCRIPTOL_IDENTIFIER );
        r( wxSTC_SCRIPTOL_STRINGEOL );
        r( wxSTC_SCRIPTOL_CLASSNAME );
        r( wxSTC_SCRIPTOL_COMMENTBLOCK );
        r( wxSTC_SCRIPTOL_CSTYLE );
        r( wxSTC_SCRIPTOL_KEYWORD );
        r( wxSTC_SCRIPTOL_PERSISTENT );
        r( wxSTC_SCRIPTOL_TRIPLE );
        r( wxSTC_SCRIPTOL_WHITE );
        r( wxSTC_SH_BACKTICKS );
        r( wxSTC_SH_CHARACTER );
        r( wxSTC_SH_COMMENTLINE );
        r( wxSTC_SH_DEFAULT );
        r( wxSTC_SH_ERROR );
        r( wxSTC_SH_HERE_DELIM );
        r( wxSTC_SH_HERE_Q );
        r( wxSTC_SH_IDENTIFIER );
        r( wxSTC_SH_NUMBER );
        r( wxSTC_SH_OPERATOR );
        r( wxSTC_SH_PARAM );
        r( wxSTC_SH_SCALAR );
        r( wxSTC_SH_STRING );
        r( wxSTC_SH_WORD );
        r( wxSTC_SN_CODE );
        r( wxSTC_SN_COMMENTLINE );
        r( wxSTC_SN_COMMENTLINEBANG );
        r( wxSTC_SN_DEFAULT );
        r( wxSTC_SN_IDENTIFIER );
        r( wxSTC_SN_NUMBER );
        r( wxSTC_SN_OPERATOR );
        r( wxSTC_SN_PREPROCESSOR );
        r( wxSTC_SN_REGEXTAG );
        r( wxSTC_SN_SIGNAL );
        r( wxSTC_SN_STRING );
        r( wxSTC_SN_STRINGEOL );
        r( wxSTC_SN_USER );
        r( wxSTC_SN_WORD );
        r( wxSTC_SN_WORD2 );
        r( wxSTC_SN_WORD3 );
        r( wxSTC_SPICE_COMMENTLINE );
        r( wxSTC_SPICE_DEFAULT );
        r( wxSTC_SPICE_DELIMITER );
        r( wxSTC_SPICE_IDENTIFIER );
        r( wxSTC_SPICE_KEYWORD );
        r( wxSTC_SPICE_KEYWORD2 );
        r( wxSTC_SPICE_KEYWORD3 );
        r( wxSTC_SPICE_NUMBER );
        r( wxSTC_SPICE_VALUE );
        r( wxSTC_SQL_CHARACTER );
        r( wxSTC_SQL_COMMENT );
        r( wxSTC_SQL_COMMENTDOC );
        r( wxSTC_SQL_COMMENTDOCKEYWORD );
        r( wxSTC_SQL_COMMENTDOCKEYWORDERROR );
        r( wxSTC_SQL_COMMENTLINE );
        r( wxSTC_SQL_COMMENTLINEDOC );
        r( wxSTC_SQL_DEFAULT );
        r( wxSTC_SQL_IDENTIFIER );
        r( wxSTC_SQL_NUMBER );
        r( wxSTC_SQL_OPERATOR );
        r( wxSTC_SQL_QUOTEDIDENTIFIER );
        r( wxSTC_SQL_SQLPLUS );
        r( wxSTC_SQL_SQLPLUS_COMMENT );
        r( wxSTC_SQL_SQLPLUS_PROMPT );
        r( wxSTC_SQL_STRING );
        r( wxSTC_SQL_USER1 );
        r( wxSTC_SQL_USER2 );
        r( wxSTC_SQL_USER3 );
        r( wxSTC_SQL_USER4 );
        r( wxSTC_SQL_WORD );
        r( wxSTC_SQL_WORD2 );
        r( wxSTC_ST_ASSIGN );
        r( wxSTC_ST_BINARY );
        r( wxSTC_ST_BOOL );
        r( wxSTC_ST_CHARACTER );
        r( wxSTC_ST_COMMENT );
        r( wxSTC_ST_DEFAULT );
        r( wxSTC_ST_GLOBAL );
        r( wxSTC_ST_KWSEND );
        r( wxSTC_ST_NIL );
        r( wxSTC_ST_NUMBER );
        r( wxSTC_ST_RETURN );
        r( wxSTC_ST_SELF );
        r( wxSTC_ST_SPECIAL );
        r( wxSTC_ST_SPEC_SEL );
        r( wxSTC_ST_STRING );
        r( wxSTC_ST_SUPER );
        r( wxSTC_ST_SYMBOL );
        r( wxSTC_START );
        r( wxSTC_STARTACTION );
        r( wxSTC_SEL_STREAM );
        r( wxSTC_SEL_RECTANGLE );
        r( wxSTC_SEL_LINES );

        r( wxEVT_STC_CHANGE );
        r( wxEVT_STC_STYLENEEDED );
        r( wxEVT_STC_CHARADDED );
        r( wxEVT_STC_SAVEPOINTREACHED );
        r( wxEVT_STC_SAVEPOINTLEFT );
        r( wxEVT_STC_ROMODIFYATTEMPT );
        r( wxEVT_STC_KEY );
        r( wxEVT_STC_DOUBLECLICK );
        r( wxEVT_STC_UPDATEUI );
        r( wxEVT_STC_MODIFIED );
        r( wxEVT_STC_MACRORECORD );
        r( wxEVT_STC_MARGINCLICK );
        r( wxEVT_STC_NEEDSHOWN );
        r( wxEVT_STC_PAINTED );
        r( wxEVT_STC_USERLISTSELECTION );
        r( wxEVT_STC_URIDROPPED );
        r( wxEVT_STC_DWELLSTART );
        r( wxEVT_STC_DWELLEND );
        r( wxEVT_STC_START_DRAG );
        r( wxEVT_STC_DRAG_OVER );
        r( wxEVT_STC_DO_DROP );
        r( wxEVT_STC_ZOOM );
        r( wxEVT_STC_HOTSPOT_CLICK );
        r( wxEVT_STC_HOTSPOT_DCLICK );
        r( wxEVT_STC_CALLTIP_CLICK );
        r( wxEVT_STC_INDICATOR_CLICK );
        r( wxEVT_STC_INDICATOR_RELEASE );
        r( wxEVT_STC_AUTOCOMP_CANCELLED );
        r( wxEVT_STC_AUTOCOMP_CHAR_DELETED );
        break;
    case 'T':
        r( wxSTC_TIME_FOREVER );
        r( wxSTC_TEX_DEFAULT );
        r( wxSTC_TEX_SPECIAL );
        r( wxSTC_TEX_GROUP );
        r( wxSTC_TEX_SYMBOL );
        r( wxSTC_TEX_COMMAND );
        r( wxSTC_TEX_TEXT );
        r( wxSTC_T3_BLOCK_COMMENT );
        r( wxSTC_T3_BRACE );
        r( wxSTC_T3_DEFAULT );
        r( wxSTC_T3_D_STRING );
        r( wxSTC_T3_HTML_DEFAULT );
        r( wxSTC_T3_HTML_STRING );
        r( wxSTC_T3_HTML_TAG );
        r( wxSTC_T3_IDENTIFIER );
        r( wxSTC_T3_KEYWORD );
        r( wxSTC_T3_LIB_DIRECTIVE );
        r( wxSTC_T3_LINE_COMMENT );
        r( wxSTC_T3_MSG_PARAM );
        r( wxSTC_T3_NUMBER );
        r( wxSTC_T3_OPERATOR );
        r( wxSTC_T3_PREPROCESSOR );
        r( wxSTC_T3_S_STRING );
        r( wxSTC_T3_USER1 );
        r( wxSTC_T3_USER2 );
        r( wxSTC_T3_USER3 );
        r( wxSTC_T3_X_DEFAULT );
        r( wxSTC_T3_X_STRING );
        r( wxSTC_TCL_BLOCK_COMMENT );
        r( wxSTC_TCL_COMMENT );
        r( wxSTC_TCL_COMMENTLINE );
        r( wxSTC_TCL_COMMENT_BOX );
        r( wxSTC_TCL_DEFAULT );
        r( wxSTC_TCL_EXPAND );
        r( wxSTC_TCL_IDENTIFIER );
        r( wxSTC_TCL_IN_QUOTE );
        r( wxSTC_TCL_MODIFIER );
        r( wxSTC_TCL_NUMBER );
        r( wxSTC_TCL_OPERATOR );
        r( wxSTC_TCL_SUBSTITUTION );
        r( wxSTC_TCL_SUB_BRACE );
        r( wxSTC_TCL_WORD );
        r( wxSTC_TCL_WORD2 );
        r( wxSTC_TCL_WORD3 );
        r( wxSTC_TCL_WORD4 );
        r( wxSTC_TCL_WORD5 );
        r( wxSTC_TCL_WORD6 );
        r( wxSTC_TCL_WORD7 );
        r( wxSTC_TCL_WORD8 );
        r( wxSTC_TCL_WORD_IN_QUOTE );
        break;
    case 'V':
        r( wxSTC_VISIBLE_SLOP );
        r( wxSTC_VISIBLE_STRICT );
        r( wxSTC_VHDL_ATTRIBUTE );
        r( wxSTC_VHDL_COMMENT );
        r( wxSTC_VHDL_COMMENTLINEBANG );
        r( wxSTC_VHDL_DEFAULT );
        r( wxSTC_VHDL_IDENTIFIER );
        r( wxSTC_VHDL_KEYWORD );
        r( wxSTC_VHDL_NUMBER );
        r( wxSTC_VHDL_OPERATOR );
        r( wxSTC_VHDL_STDFUNCTION );
        r( wxSTC_VHDL_STDOPERATOR );
        r( wxSTC_VHDL_STDPACKAGE );
        r( wxSTC_VHDL_STDTYPE );
        r( wxSTC_VHDL_STRING );
        r( wxSTC_VHDL_STRINGEOL );
        r( wxSTC_VHDL_USERWORD );
        r( wxSTC_V_COMMENT );
        r( wxSTC_V_COMMENTLINE );
        r( wxSTC_V_COMMENTLINEBANG );
        r( wxSTC_V_DEFAULT );
        r( wxSTC_V_IDENTIFIER );
        r( wxSTC_V_NUMBER );
        r( wxSTC_V_OPERATOR );
        r( wxSTC_V_PREPROCESSOR );
        r( wxSTC_V_STRING );
        r( wxSTC_V_STRINGEOL );
        r( wxSTC_V_USER );
        r( wxSTC_V_WORD );
        r( wxSTC_V_WORD2 );
        r( wxSTC_V_WORD3 );
        break;
    case 'W':
        r( wxSTC_WRAP_NONE );
        r( wxSTC_WRAP_WORD );
        r( wxSTC_WRAP_CHAR );

        r( wxSTC_WRAPVISUALFLAGLOC_DEFAULT );
        r( wxSTC_WRAPVISUALFLAGLOC_END_BY_TEXT );
        r( wxSTC_WRAPVISUALFLAGLOC_START_BY_TEXT );
        r( wxSTC_WRAPVISUALFLAG_END );
        r( wxSTC_WRAPVISUALFLAG_NONE );
        r( wxSTC_WRAPVISUALFLAG_START );

        r( wxSTC_WS_INVISIBLE );
        r( wxSTC_WS_VISIBLEALWAYS );
        r( wxSTC_WS_VISIBLEAFTERINDENT );
        break;
    case 'Y':
        r( wxSTC_YAML_COMMENT );
        r( wxSTC_YAML_DEFAULT );
        r( wxSTC_YAML_DOCUMENT );
        r( wxSTC_YAML_ERROR );
        r( wxSTC_YAML_IDENTIFIER );
        r( wxSTC_YAML_KEYWORD );
        r( wxSTC_YAML_NUMBER );
        r( wxSTC_YAML_OPERATOR );
        r( wxSTC_YAML_REFERENCE );
        r( wxSTC_YAML_TEXT );
        break;
    }
#undef r

    WX_PL_CONSTANT_CLEANUP();
}

wxPlConstants stc_module( &stc_constant );
